[![PyPI version](https://badge.fury.io/py/csbdeep.svg)](https://pypi.org/project/csbdeep)
[![Test](https://github.com/CSBDeep/CSBDeep/workflows/Test/badge.svg)](https://github.com/CSBDeep/CSBDeep/actions?query=workflow%3ATest)
[![Test (PyPI)](https://github.com/CSBDeep/CSBDeep/workflows/Test%20(PyPI)/badge.svg)](https://github.com/CSBDeep/CSBDeep/actions?query=workflow%3A%22Test+%28PyPI%29%22)
[![Test (Legacy)](https://github.com/CSBDeep/CSBDeep/workflows/Test%20(Legacy)/badge.svg)](https://github.com/CSBDeep/CSBDeep/actions?query=workflow%3A%22Test+%28Legacy%29%22)

# CSBDeep – a toolbox for CARE

This is the CSBDeep Python package, which provides a toolbox for content-aware restoration of fluorescence microscopy images (CARE), based on deep learning via Keras and TensorFlow.

Please see the documentation at http://csbdeep.bioimagecomputing.com/doc/.
